@@ -1,6 +1,6 @@
 package Statocles;
 {
-  $Statocles::VERSION = '0.005';
+  $Statocles::VERSION = '0.006';
 }
 # ABSTRACT: A static site generator
 
@@ -19,7 +19,7 @@ Statocles - A static site generator
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 DESCRIPTION
 
@@ -27,7 +27,21 @@ Statocles is a tool for building static HTML pages from documents.
 
 =head2 DOCUMENTS
 
-A document is a data structure. The default store reads documents in YAML.
+A document is a data structure. The default store reads documents in a combined
+YAML and Markdown format.
+
+Documents are formatted with a YAML document on top, and Markdown content
+on the bottom, like so:
+
+    ---
+    title: This is a title
+    author: preaction
+    ---
+    # This is the markdown content
+    
+    This is a paragraph
+
+This is the same format that L<http://jekyllrb.com|Jekyll> uses.
 
 =head2 PAGES
 
